"""Helper tags and filters easing the handling of bidi in templates

"""
from django import template
from django.template.defaultfilters import stringfilter
from django.utils import translation

register = template.Library()

def add_direction(value, arg=u"rtl_only"):
    """Adds direction to the element

    :arguments:
        arg
            * rtl_only: Add the direction only in case of a
              right-to-left language (default)
            * both: add the direction in both case
            * ltr_only: Add the direction only in case of a
              left-to-right language

    {{image_name|add_direction}} when image_name is 'start_arrow.png'
    results in 'start_arrow_rtl.png' in case of RTL language, and
    'start_arrow.png' or 'start_arrow_ltr.png' depends on `arg` value.

    """

    if arg == u'rtl_only':
        directions = (u'', u'_rtl')
    elif arg == u'both':
        directions = (u'_ltr', u'_rtl')
    elif arg == u'ltr_only':
        directions = (u'_ltr', u'')
    else:
        raise template.TemplateSyntaxError('add_direction can use arg with one of ["rtl_only", "both", "ltr_only"]')

    parts = value.rsplit('.', 1)
    if not len(parts):
        return value
    elif len(parts) == 1:
        return value + directions[translation.get_language_bidi()]
    else:
        return '.'.join((parts[0]+directions[translation.get_language_bidi()],parts[1]))
add_direction.is_safe = True

register.filter(add_direction)


# -*- coding: utf-8 -*-
#!/usr/bin/env python

import os
import sys

import bidiutils

try:
    from setuptools import setup, Command
except ImportError:
    from distutils.core import setup, Command

version = bidiutils.__version__

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    print("You probably want to also tag the version now:")
    print("  git tag -a %s -m 'version %s'" % (version, version))
    print("  git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')


class PyTest(Command):
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        import sys, subprocess
        errno = subprocess.call([sys.executable, 'runtests.py'])
        raise SystemExit(errno)

setup(
    name='django-bidi-utils',
    version=version,
    description='context processors and filters for handling Bi-directional (BiDi) in django templates',
    long_description=readme + '\n\n' + history,
    author='Meir Kriheli',
    author_email='mkriheli@gmail.com',
    url='https://github.com/MeirKriheli/django-bidi-utils',
    packages=[
        'bidiutils',
    ],
    include_package_data=True,
    install_requires=[
    ],
    cmdclass={'test': PyTest},
    license="MIT",
    zip_safe=False,
    keywords='django-bidi-utils',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
    ],
)
